// Copyright 2019 github.com. All rights reserved.
// Use of this source code is governed by github.com.

package v1

import (
	"smart-supplier-management-gateway/param/base"
	"smart-supplier-management-gateway/pb/v1"
)


type DeviceDockingBody struct {
	DeviceType int32 `form:"device_type" json:"device_type"`
}

type DeviceDockingRequest struct {
	base.Header
	DeviceDockingBody
}

type DeviceDockingResponse struct {
	base.Result
	Data v1.DeviceDockingReply `json:"data"`
}

type DeviceAddBody struct {
	ProjectId int64   `json:"project_id" form:"project_id"`
	Name   string  `json:"name" form:"name"`
	Sn     string  `json:"sn" form:"sn"`
	Addr   string  `json:"addr" form:"addr"`
	Type   int32  `json:"type" form:"type"`
	Lon    float32 `json:"lon" form:"lon"`
	Lat    float32 `json:"lat" form:"lat"`
	XCoord float32 `json:"x_coord" form:"x_coord"`
	YCoord float32 `json:"y_coord" form:"y_coord"`
	CameraCount int32 `json:"camera_count" form:"camera_count"`
}

type DeviceAddRequest struct {
	base.Header
	DeviceAddBody
}

type DeviceAddResponse struct {
	base.Result
	Data v1.DeviceAddReply `json:"data"`
}

type DeviceDelBody struct {
	Id int64 `form:"id"`
	Reason string `form:"reason"`
}

type DeviceDelRequest struct {
	base.Header
	DeviceDelBody
}

type DeviceDelResponse struct {
	base.Result
}

type DeviceTypeListQuery struct {
	IsAll bool `form:"is_all"`
	// 0 待对接测试 1 测试通过 2对接测试未通过 3. 审核通过 3 审核未通过
	StatusFilters string `form:"status_filters"`
	IncludeVedio bool `form:"include_vedio"`
}

type DeviceTypeListRequest struct {
	base.Header
	DeviceTypeListQuery
}

type DeviceTypeListResponse struct {
	base.Result
	Data []*v1.DeviceTypeItem `json:"data"`
}

type DeviceListQuery struct {
	// 审核状态 0 待审核 1 通过 2 未通过 3 待拆机 4 拆机审核未通过
	FilterStatus string `form:"filter_status"`
	ProjectId int64 `form:"project_id"`
	Filter string `form:"filter"`
	Page int32 `form:"page"`
	TypeCode int `form:"type_code"`
	CanDel bool `form:"can_del"`
}

type DeviceListRequest struct {
	base.Header
	DeviceListQuery
}

type DeviceListResponse struct {
	base.Result
	Data v1.DeviceListReply `json:"data"`
}

type DeviceDelJobListQuery struct {
	Page int32 `form:"page"`
	// 审核状态 0 待审核 1 通过 2 未通过
	FilterStatus string `form:"filter_status"`
	Filter string `form:"filter"`
}

type DeviceDelJobListRequest struct {
	base.Header
	DeviceDelJobListQuery
}

type DeviceDelJobListResponse struct {
	base.Result
	Data v1.DeviceDelJobListReply `json:"data"`
}


type ProjectListRequest struct {
	base.Header
}

type ProjectListResponse struct {
	base.Result
	Data []*v1.ProjectItem `json:"data"`
}

type ChannelAddBody struct {
	Sn string `form:"sn"`
	ChannelCount int32 `form:"channel_count"`
}

type ChannelAddRequest struct {
	base.Header
	ChannelAddBody
}

type ChannelAddResponse struct {
	base.Result
}

type ChannelListQuery struct {
	Sn string `form:"sn"`
	ChannelNo string `form:"channel_no"`
	Page int32 `form:"page"`
}

type ChannelListRequest struct {
	base.Header
	ChannelListQuery
}

type ChannelListResponse struct {
	base.Result
	Data v1.ChannelListReply `json:"data"`
}

type ChannelUpdateBody struct {
	Id int64 `form:"id"`
	Name string `form:"name"`
}

type ChannelUpdateRequest struct {
	base.Header
	ChannelUpdateBody
}

type ChannelUpdateResponse struct {
	base.Result
}

type VedioAddBody struct {
	ProjectId int64 `form:"project_id"`
	VedioType int32 `form:"vedio_type"`
	Name string `form:"name"`
	ChannelCount int32 `form:"channel_count"`
}

type VedioAddRequest struct {
	base.Header
	VedioAddBody
}

type VedioAddResponse struct {
	base.Result
	Data v1.VedioAddReply `json:"data"`
}

type VedioListQuery struct {
	// 审核状态 0 待审核 1 通过 2 未通过
	FilterStatus string `form:"filter_status"`
	ProjectId int64 `form:"project_id"`
	Filter string `form:"filter"`
	Page int32 `form:"page"`
}

type VedioListRequest struct {
	base.Header
	VedioListQuery
}

type VedioListResponse struct {
	base.Result
	Data v1.VedioListReply `json:"data"`
}

type DeviceAllTypeListResponse struct {
	base.Result
	Data v1.DeviceTypeListReply `json:"data"`
}
