// Copyright 2019 github.com. All rights reserved.
// Use of this source code is governed by github.com.

package v1

import (
	"smart-supplier-management-gateway/param/base"
	"smart-supplier-management-gateway/pb/v1"
)


type RegisterBody struct {
	// 供应商名称
	Name string `gorm:"column:name" json:"name" form:"name"`
	// 社会信用码
	SocialCode string `gorm:"column:social_code" json:"social_code" form:"social_code"`
	// 法人
	LegalPerson string `gorm:"column:legal_person" json:"legal_person" form:"legal_person"`
	// 身份证
	IdCert string `gorm:"column:id_cert" json:"id_cert" form:"id_cert"`
	// 企业所属 0，省内 1 省外  省外企业须上传业务负责人任命书
	EnterpriseLocation int32 `gorm:"column:enterprise_location" json:"enterprise_location" form:"enterprise_location"`
	// 营业执照
	BusinessLicense []string `gorm:"column:business_license" json:"business_license" form:"business_license"`
	// 诚信经营承诺书
	IntegrityManagementLetter []string `gorm:"column:integrity_management_letter" json:"integrity_management_letter" form:"integrity_management_letter"`
	// 法人授权书
	LegalPersonLetter []string `gorm:"column:legal_person_letter" json:"legal_person_letter" form:"legal_person_letter"`
	// 业务负责人任命书
	BusinessResponsibleLetter []string `gorm:"column:business_responsible_letter" json:"business_responsible_letter" form:"business_responsible_letter"`
	// 登录名
	UserName string `gorm:"column:user_name" json:"user_name" form:"user_name"`
	// 密码
	Passwd string `gorm:"column:passwd" json:"passwd" form:"passwd"`
	// 业务联系人
	BusinessContact string `gorm:"column:business_contact" json:"business_contact" form:"business_contact"`
	// 业务联系人电话
	BusinessContactPhone string `gorm:"column:business_contact_phone" json:"business_contact_phone" form:"business_contact_phone"`
	// 业务负责人
	BusinessResponsible string `gorm:"column:business_responsible" json:"business_responsible" form:"business_responsible"`
	// 业务负责人电话
	BusinessResponsiblePhone string `gorm:"column:business_responsible_phone" json:"business_responsible_phone" form:"business_responsible_phone"`
	// 应急联系人
	EmergencyContact string `gorm:"column:emergency_contact" json:"emergency_contact" form:"emergency_contact"`
	EmergencyContactPhone string `gorm:"column:emergency_contact_phone" json:"emergency_contact_phone" form:"emergency_contact_phone"`
	// 验证码
	Verify string `form:"verify"`
}

type RegisterRequest struct {
	RegisterBody
}

type RegisterResponse struct {
	base.Result
	Data v1.RegisterReply `json:"data"`
}

type LoginBody struct {
	User string `form:"user"`
	Password string `form:"password"`
	Verify string `form:"verify"`
	Captcha string `form:"captcha"`
}

type LoginRequest struct {
	LoginBody
}

type LoginData struct {
	Uid int64 `json:"uid"`
	Token string `json:"token"`
	RefreshToken string `json:"refresh_token"`
}

type LoginResponse struct {
	base.Result
	Data LoginData `json:"data"`
}

type TokenRequest struct {
	base.Header
}

type TokenResponse struct {
	base.Result
	Data string `json:"data"`
}

type PublicityQuery struct {
	DeviceCode int `form:"device_code"`
	Provider string `form:"provider"`
}

type PublicityRequest struct {
	PublicityQuery
}

type PublicityItem struct {
	Name                 string                     `json:"name"`
	SocialCode           string                     `json:"social_code"`
}

type PublicityData struct {
	List []PublicityItem `json:"list"`
}
type PublicityResponse struct {
	base.Result
	Data PublicityData `json:"data"`
}

type VcodeQuery struct {
	Phone string `form:"phone"`
}

type VcodeRequest struct {
	VcodeQuery
}

type VcodeResponse struct {
	base.Result
	Data v1.GetVcodeReply `json:"data"`
}

type FindPasswdVerifyBody struct {
	Phone string `form:"phone"`
	Verify string `form:"verify"`
	Vcode uint32 `form:"vcode"`
	Captcha string `form:"captcha"`
}

type FindPasswdVerifyRequest struct {
	FindPasswdVerifyBody
}

type FindPasswdVerifyResponse struct {
	base.Result
}

type SetPasswdBody struct {
	Phone string `form:"phone"`
	Passwd string `form:"passwd"`
	Vcode int32 `form:"vcode"`
}

type SetPasswdRequest struct {
	SetPasswdBody
}

type SetPasswdResponse struct {
	base.Result
}

type ProviderApproveStatusQuery struct {
	SocialCode string `form:"social_code"`
}
type ProviderApproveStatusRequest struct {
	base.Header
	ProviderApproveStatusQuery
}
type ProviderApproveStatusResponse struct {
	base.Result
	Data v1.ProviderApproveStatusReply `json:"data"`
}


type ChangePasswdBody struct {
	Old string `form:"old"`
	New string `form:"new"`
}

type ChangePasswdRequest struct {
	base.Header
	ChangePasswdBody
}

type ChangePasswdResponse struct {
	base.Result
}

type LogListQuery struct {
	Page int32 `form:"page"`
	Start int64 `form:"start"`
	End int64 `form:"end"`
}

type LogListRequest struct {
	base.Header
	LogListQuery
}

type LogListResponse struct {
	base.Result
	Data v1.LogListReply `json:"data"`
}

type CaptchaIdRequest struct {

}

type CaptchaIdData struct {
	CaptureId string `json:"capture_id"`
}
type CaptchaIdResponse struct {
	base.Result
	Data CaptchaIdData `json:"data"`
}

type CaptchaPngPath struct {
	CaptchaId string `uri:"captcha_id"`
}

type CaptchaPngRequest struct {
	CaptchaPngPath
}

type CaptchaPngResponse struct {
}

type MailUpdateQuery struct {
	Token string `form:"token"`
}
type MailUpdateRequest struct {
	MailUpdateQuery
}

type MailUpdateResponse struct {
	base.Result
}

type MailPrepareBody struct {
	Email string `form:"email"`
	Password string `form:"password"`
}
type MailPrepareRequest struct {
	base.Header
	MailPrepareBody
}

type MailPrepareResponse struct {
	base.Result
}

type PhoneUpdateBody struct {
	Phone string `form:"phone"`
	Vcode uint32 `form:"vcode"`
}

type PhoneUpdateRequest struct {
	base.Header
	PhoneUpdateBody
}

type PhoneUpdateResponse struct {
	base.Result
}

type UserInfoRequest struct {
	base.Header
}

type UserInfoResponse struct {
	base.Result
	Data v1.UserInfoReply `json:"data"`
}



